package models

import (
	"wechat-conf/models/model"
	"wechat-conf/utils"
)

// ComponentInit 初始化第三方
func ComponentInit() {
	var conf = model.SysComponentConf{}

	_, err := DBEngine.Get(&conf)
	if err != nil {
		utils.LogError("初始化第三方失败：", err)
		return
	}
	utils.LogError("获取第三方信息：", conf)
	if conf.Appid == "" {
		utils.LogError("初始化第三方数据失败，数据为空")
		return
	}
	var cert = map[string]string{
		"appid":                 conf.Appid,
		"aeskey":                conf.Aeskey,
		"secret":                conf.Secret,
		"componentVerifyTicket": conf.Ticket,
	}

	utils.ComponentInit(cert)
}

// InitWechat 初始化微信
func InitWechat() {
	var wxconfs []model.SysWechatConf
	err := DBEngine.Where("status=1").Find(&wxconfs)
	if err != nil {
		utils.LogError("初始化微信失败：", err)
		return
	}
	for _, conf := range wxconfs {
		var cert = map[string]string{
			"authorizer_access_token":  conf.Token,
			"authorizer_refresh_token": conf.RefreshToken,
			"authorization_code":       conf.AuthorizationCode,
			"appid":                    conf.Appid,
		}
		client := utils.WechatInit(cert, UpdateToken)
		utils.AppendWxClient(client)
	}
}

// UpdateToken 更新微信token
func UpdateToken(token map[string]string) {
	var conf = model.SysWechatConf{
		Token:        token["token"],
		RefreshToken: token["refreshToken"],
		Appid:        token["appid"],
	}
	sql := `update sys_wechat_conf set token=?,refresh_token=? where appid=?`
	_, err := DBEngine.Exec(sql, conf.Token, conf.RefreshToken, conf.Appid)
	if err != nil {
		utils.LogError("更新微信token失败：", err)
	}
}
